@@ -14,6 +14,13 @@ initResourcePaths <- function() {
 #' @importFrom methods loadMethod
 .onAttach <- function(libname, pkgname){
   shiny::registerInputHandler("shinyTree", function(val, shinysession, name){
+    #The callbackCounter exists to make sure shiny gets an update after this sequence:
+    #1. The user changes the tree
+    #2. The R server restores the tree back to the previous version (because of logic that prevents the user change)
+    #3. The user tries to make the same change.
+    #Because the tree would otherwise send the same json message twice, shiny blocks the message. By havng an incrementing
+    #callbackCounter, the app is assured to receive the message
+    val$callbackCounter <- NULL #set to null to avoid problems with jsonToAttr
     jsonToAttr(val)    
   })
 }
@@ -41,6 +48,9 @@ jsonToAttr <- function(json){
 
 supplementAttr <- function(ret, json){
   # Only add attributes if non-default
+  #cat("JSON string:\n")
+  #cat(str(json))
+  
   if (json$state$selected != FALSE){
     attr(ret, "stselected") <- json$state$selected
   }
@@ -50,5 +60,14 @@ supplementAttr <- function(ret, json){
   if (json$state$opened != FALSE){
     attr(ret, "stopened") <- json$state$opened
   }
+  if (exists('stid', where=json)) {
+    attr(ret, "stid") <- json$stid
+  }
+  if (exists('stclass', where=json)) {
+    attr(ret, "stclass") <- json$stclass
+  }
+  if (exists('id', where=json)) {
+    attr(ret, "id") <- json$id
+  }
   ret
-}
\ No newline at end of file
+}
