@@ -16,4 +16,16 @@ renderTree <- function(expr, env = parent.frame(), quoted = FALSE){
     
     shiny::HTML(as.character(listToTags(tree)))
   })
-}
\ No newline at end of file
+}
+
+#' Render an empty ShinyTree
+#' 
+#' Renders a tree with no defined nodes.
+#' \code{\link{shinyTree}}.
+#'
+#' @seealso \code{\link{shinyTree}}
+#' @export
+renderEmptyTree <- function() {
+  return(function(shinysession, name) {
+  })
+}
